Jupyter widget facilitating interactive visualization of spatial single-cell data with Vitessce

Package Install
---------------

**Prerequisites**
- [node](http://nodejs.org/)

```bash
npm install --save vitessce-jupyter
```

To deploy as a package to NPM (required for use with Jupyter Lab):

```sh
npm publish
```